# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 设备固件升级任务已经完成。
FAILEDOPERATION_DEVICEFIRMWARETASKALREADDONE = 'FailedOperation.DeviceFirmwareTaskAlreadDone'

# 设备正在升级中。
FAILEDOPERATION_DEVICEISUPDATING = 'FailedOperation.DeviceIsUpdating'

# 设备已经运行其他ota升级任务。
FAILEDOPERATION_DEVICERUNNINGOTHEROTATASK = 'FailedOperation.DeviceRunningOtherOtaTask'

# 无相关操作权限。
FAILEDOPERATION_PERMISSIONDENIED = 'FailedOperation.PermissionDenied'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 固件已存在。
INVALIDPARAMETERVALUE_FIRMWAREALREADYEXIST = 'InvalidParameterValue.FirmwareAlreadyExist'

# 设备固件升级任务不存在。
RESOURCENOTFOUND_DEVICEFIRMWARETASKNOTEXIST = 'ResourceNotFound.DeviceFirmwareTaskNotExist'

# 设备无固件版本。
RESOURCENOTFOUND_DEVICEHASNOFIRMWARE = 'ResourceNotFound.DeviceHasNoFirmware'

# 固件不存在。
RESOURCENOTFOUND_FIRMWARENOTEXIST = 'ResourceNotFound.FirmwareNotExist'

# 固件升级任务不存在。
RESOURCENOTFOUND_FIRMWARETASKNOTEXIST = 'ResourceNotFound.FirmwareTaskNotExist'

# 未知参数错误。
UNKNOWNPARAMETER = 'UnknownParameter'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'
